@@ -1,9 +1,10 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -31,6 +32,7 @@
 #include "exports.h"
 
 class AvatarService;
+class Buddy;
 class Contact;
 
 class KADUAPI AvatarManager : public QObject, public SimpleManager<Avatar>, AccountsAwareObject
@@ -45,6 +47,8 @@ class KADUAPI AvatarManager : public QObject, public SimpleManager<Avatar>, Acco
 	AvatarManager();
 	virtual ~AvatarManager();
 
+	void init();
+
 	bool needUpdate(const Contact &contact);
 
 private slots:
