@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -110,6 +111,11 @@ void GroupShared::store()
 	storeValue("TabPosition", TabPosition);
 }
 
+void GroupShared::aboutToBeRemoved()
+{
+	emit groupAboutToBeRemoved();
+}
+
 void GroupShared::setName(const QString &name)
 {
 	ensureLoaded();
