@@ -1,8 +1,9 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2009, 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +22,6 @@
 
 #include "accounts/account-manager.h"
 #include "buddies/buddy-set.h"
-#include "buddies/buddy-shared.h"
 #include "protocols/protocol.h"
 
 #include "chat/aggregate-chat-manager.h"
@@ -33,19 +33,16 @@ AggregateChatManager * AggregateChatManager::Instance = 0;
 AggregateChatManager * AggregateChatManager::instance()
 {
 	if (!Instance)
+	{
 		Instance = new AggregateChatManager();
+		Instance->init();
+	}
 
 	return Instance;
 }
 
-
 AggregateChatManager::AggregateChatManager()
 {
-	connect(ChatManager::instance(), SIGNAL(chatAdded(Chat)), this, SLOT(chatAdded(Chat)));
-	connect(ChatManager::instance(), SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
-
-	foreach (const Chat &chat, ChatManager::instance()->allItems())
-		chatAdded(chat);
 }
 
 AggregateChatManager::~AggregateChatManager()
@@ -53,17 +50,26 @@ AggregateChatManager::~AggregateChatManager()
 	disconnect(ChatManager::instance(), SIGNAL(chatAdded(Chat)), this, SLOT(chatAdded(Chat)));
 	disconnect(ChatManager::instance(), SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
 
-	foreach (const Chat &chat, ChatManager::instance()->allItems())
+	foreach (const Chat &chat, ChatManager::instance()->items())
 		chatRemoved(chat);
 }
 
+void AggregateChatManager::init()
+{
+	connect(ChatManager::instance(), SIGNAL(chatAdded(Chat)), this, SLOT(chatAdded(Chat)));
+	connect(ChatManager::instance(), SIGNAL(chatRemoved(Chat)), this, SLOT(chatRemoved(Chat)));
+
+	foreach (const Chat &chat, ChatManager::instance()->items())
+		chatAdded(chat);
+}
+
 void AggregateChatManager::chatAdded(const Chat &chat)
 {
 	BuddySet buddies = chat.contacts().toBuddySet();
 
 	if (!AggregateChats.contains(buddies))
 	{
-		QList<Chat> chats;
+		QVector<Chat> chats;
 		chats.append(chat);
 		AggregateChats.insert(buddies, chats);
 	}
@@ -78,7 +84,7 @@ void AggregateChatManager::chatRemoved(const Chat &chat)
 	if (!AggregateChats.contains(buddies))
 		return;
 
-	AggregateChats[buddies].removeAll(chat);
+	AggregateChats[buddies].remove(AggregateChats[buddies].indexOf(chat));
 	if (AggregateChats.value(buddies).isEmpty())
 		AggregateChats.remove(buddies);
 }
@@ -101,16 +107,15 @@ Chat AggregateChatManager::aggregateChat(const BuddySet &buddies)
 	if (!AggregateChats.contains(buddies))
 		return Chat::null;
 
-	QList<Chat> chats = AggregateChats.value(buddies);
+	QVector<Chat> chats = AggregateChats.value(buddies);
 	if (chats.count() <= 1)
 		return Chat::null;
 
 	Chat result = Chat::create();
-	result.setType(chats.at(0).type());
+	result.setType("Aggregate");
 
-	ChatDetailsAggregate *details = new ChatDetailsAggregate(result);
+	ChatDetailsAggregate *details = qobject_cast<ChatDetailsAggregate *>(result.details());
 	details->setChats(chats);
-	result.setDetails(details);
 
 	return result;
 }
