@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,12 +24,12 @@
 
 #include "accounts/account-manager.h"
 #include "buddies/buddy-preferred-manager.h"
-#include "chat/type/chat-type-manager.h"
 #include "chat/chat-details-conference.h"
 #include "chat/chat-details-simple.h"
-#include "contacts/contact-shared.h"
+#include "chat/type/chat-type-manager.h"
+#include "message/message-manager.h"
 
-#include "chat/chat-manager.h"
+#include "chat-manager.h"
 
 ChatManager * ChatManager::Instance = 0;
 
@@ -41,7 +41,10 @@ ChatManager * ChatManager::Instance = 0;
 ChatManager *  ChatManager::instance()
 {
 	if (0 == Instance)
+	{
 		Instance = new ChatManager();
+		Instance->init();
+	}
 
 	return Instance;
 }
@@ -52,10 +55,30 @@ ChatManager::ChatManager()
 
 ChatManager::~ChatManager()
 {
+	disconnect(MessageManager::instance(), SIGNAL(unreadMessageAdded(Message)),
+	           this, SLOT(unreadMessageAdded(Message)));
+	disconnect(MessageManager::instance(), SIGNAL(unreadMessageRemoved(Message)),
+	           this, SLOT(unreadMessageRemoved(Message)));
+
+	foreach (const Message &message, MessageManager::instance()->allUnreadMessages())
+		unreadMessageRemoved(message);
+}
+
+void ChatManager::init()
+{
+	foreach (const Message &message, MessageManager::instance()->allUnreadMessages())
+		unreadMessageAdded(message);
+
+	connect(MessageManager::instance(), SIGNAL(unreadMessageAdded(Message)),
+	        this, SLOT(unreadMessageAdded(Message)));
+	connect(MessageManager::instance(), SIGNAL(unreadMessageRemoved(Message)),
+	        this, SLOT(unreadMessageRemoved(Message)));
 }
 
 void ChatManager::itemAboutToBeRegistered(Chat item)
 {
+	connect(item, SIGNAL(updated()), this, SLOT(chatDataUpdated()));
+
 	emit chatAboutToBeAdded(item);
 }
 
@@ -66,6 +89,8 @@ void ChatManager::itemRegistered(Chat item)
 
 void ChatManager::itemAboutToBeUnregisterd(Chat item)
 {
+	disconnect(item, SIGNAL(updated()), this, SLOT(chatDataUpdated()));
+
 	emit chatAboutToBeRemoved(item);
 }
 
@@ -74,38 +99,6 @@ void ChatManager::itemUnregistered(Chat item)
 	emit chatRemoved(item);
 }
 
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Method is called after details for chat were loaded.
- *
- * Method is calles after details for chat were loaded. It means that
- * chat has all data loaded. It can now be registered in ChatManager
- * and itemAboutToBeAdded and itemAdded methods will be called.
- */
-void ChatManager::detailsLoaded(Chat chat)
-{
-	QMutexLocker locker(&mutex());
-
-	if (!chat.isNull())
-		registerItem(chat);
-}
-
-/**
- * @author Rafal 'Vogel' Malinowski
- * @short Method is called after details for chat were unloaded.
- *
- * Method is calles after details for chat were unloaded. It means that
- * chat has soem data unloaded. It can now be unregistered in ChatManager
- * and itemAboutToBeRemoved and itemRemoved methods will be called.
- */
-void ChatManager::detailsUnloaded(Chat chat)
-{
-	QMutexLocker locker(&mutex());
-
-	if (!chat.isNull())
-		unregisterItem(chat);
-}
-
 bool ChatManager::isAccountCommon(const Account &account, const BuddySet &buddies)
 {
 	QMutexLocker locker(&mutex());
@@ -121,8 +114,7 @@ Account ChatManager::getCommonAccount(const BuddySet &buddies)
 {
 	QMutexLocker locker(&mutex());
 
-	QList<Account> accounts = AccountManager::instance()->items();
-	foreach (const Account &account, accounts)
+	foreach (const Account &account, AccountManager::instance()->items())
 		if (isAccountCommon(account, buddies))
 			return account;
 
@@ -135,7 +127,7 @@ Chat ChatManager::findChat(const BuddySet &buddies, bool create)
 
 	if (buddies.count() == 1)
 	{
-		Contact contact = BuddyPreferredManager::instance()->preferredContactByPendingMessages(*buddies.constBegin());
+		Contact contact = BuddyPreferredManager::instance()->preferredContactByUnreadMessages(*buddies.constBegin());
 		if (!contact)
 			contact = BuddyPreferredManager::instance()->preferredContact(*buddies.constBegin());
 
@@ -184,7 +176,7 @@ Chat ChatManager::findChat(const ContactSet &contacts, bool create)
 
 	ensureLoaded();
 
-	if (contacts.size() == 0)
+	if (contacts.isEmpty())
 		return Chat::null;
 
 	// check if every contact has the same account
@@ -221,29 +213,69 @@ Chat ChatManager::findChat(const ContactSet &contacts, bool create)
 
 	Chat chat = Chat::create();
 	chat.setChatAccount(account);
-	ChatDetails *details = 0;
 
 	Contact contact = contacts.toContact();
 	if (!contact.isNull())
 	{
-		ChatDetailsSimple *simple = new ChatDetailsSimple(chat);
+		chat.setType("Simple");
+
+		ChatDetailsSimple *simple = dynamic_cast<ChatDetailsSimple *>(chat.details());
 		simple->setState(StateNew);
 		simple->setContact(contact);
-		details = simple;
 	}
 	else if (contacts.size() > 1)
 	{
-		ChatDetailsConference *conference = new ChatDetailsConference(chat);
+		// only gadu-gadu support conferences
+		// TODO: this should be done better
+		if (chat.chatAccount().protocolName() != "gadu")
+			return Chat::null;
+
+		chat.setType("Conference");
+
+		ChatDetailsConference *conference = dynamic_cast<ChatDetailsConference *>(chat.details());
 		conference->setState(StateNew);
 		conference->setContacts(contacts);
-		details = conference;
 	}
 	else
 		return Chat::null;
 
-	chat.setDetails(details);
-	chat.setType(details->type()->name());
-
 	addItem(chat);
 	return chat;
 }
+
+Chat ChatManager::byDisplay(const QString &display)
+{
+	QMutexLocker locker(&mutex());
+
+	ensureLoaded();
+
+	if (display.isEmpty())
+		return Chat::null;
+
+	foreach (const Chat &chat, allItems())
+		if (display == chat.display())
+			return chat;
+
+	return Chat::null;
+}
+
+void ChatManager::chatDataUpdated()
+{
+	Chat chat(sender());
+	if (!chat.isNull())
+		emit chatUpdated(chat);
+}
+
+void ChatManager::unreadMessageAdded(const Message &message)
+{
+	const Chat &chat = message.messageChat();
+	chat.setUnreadMessagesCount(chat.unreadMessagesCount() + 1);
+}
+
+void ChatManager::unreadMessageRemoved(const Message &message)
+{
+	const Chat &chat = message.messageChat();
+	quint16 unreadMessagesCount = chat.unreadMessagesCount();
+	if (unreadMessagesCount > 0)
+		chat.setUnreadMessagesCount(unreadMessagesCount - 1);
+}
