@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,10 +24,10 @@
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
-#include <QtGui/QComboBox>
 #include <QtGui/QCheckBox>
-#include <QtGui/QLabel>
+#include <QtGui/QComboBox>
 #include <QtGui/QHBoxLayout>
+#include <QtGui/QLabel>
 #include <QtGui/QPalette>
 #include <QtGui/QPushButton>
 
@@ -37,16 +37,16 @@
 #include "chat/html-messages-renderer.h"
 #include "chat/style-engines/chat-engine-adium/chat-engine-adium.h"
 #include "chat/style-engines/chat-engine-kadu/chat-engine-kadu.h"
-#include "chat/message/message-render-info.h"
 #include "configuration/chat-configuration-holder.h"
 #include "configuration/configuration-file.h"
 #include "core/core.h"
 #include "emoticons/emoticons-manager.h"
 #include "gui/widgets/chat-messages-view.h"
-#include "gui/widgets/preview.h"
-#include "gui/widgets/configuration/configuration-widget.h"
 #include "gui/widgets/configuration/config-group-box.h"
+#include "gui/widgets/configuration/configuration-widget.h"
+#include "gui/widgets/preview.h"
 #include "gui/windows/message-dialog.h"
+#include "message/message-render-info.h"
 #include "misc/misc.h"
 #include "protocols/protocols-manager.h"
 
@@ -57,7 +57,10 @@ ChatStylesManager * ChatStylesManager::Instance = 0;
 ChatStylesManager * ChatStylesManager::instance()
 {
 	if (0 == Instance)
+	{
 		Instance = new ChatStylesManager();
+		Instance->init();
+	}
 
 	return Instance;
 }
@@ -65,6 +68,16 @@ ChatStylesManager * ChatStylesManager::instance()
 ChatStylesManager::ChatStylesManager() :
 		CurrentEngine(0), SyntaxListCombo(0), EditButton(0), DeleteButton(0),
 		VariantListCombo(0), TurnOnTransparency(0), EnginePreview(0)
+{
+}
+
+ChatStylesManager::~ChatStylesManager()
+{
+	unregisterChatStyleEngine("Kadu");
+	unregisterChatStyleEngine("Adium");
+}
+
+void ChatStylesManager::init()
 {
 	//FIXME:
 	KaduEngine = new KaduChatStyleEngine(this);
@@ -77,12 +90,6 @@ ChatStylesManager::ChatStylesManager() :
 	configurationUpdated();
 }
 
-ChatStylesManager::~ChatStylesManager()
-{
-	unregisterChatStyleEngine("Kadu");
-	unregisterChatStyleEngine("Adium");
-}
-
 void ChatStylesManager::registerChatStyleEngine(const QString &name, ChatStyleEngine *engine)
 {
 	if (0 != engine && !RegisteredEngines.contains(name))
@@ -358,7 +365,7 @@ void ChatStylesManager::mainConfigurationWindowCreated(MainConfigurationWindow *
 	if (!defaultVariant.isEmpty() && VariantListCombo->findText(defaultVariant) == -1)
 		VariantListCombo->insertItem(0, defaultVariant);
 
-	QString newVariant = CurrentEngine->currentStyleVariant().isNull()
+	QString newVariant = CurrentEngine->currentStyleVariant().isEmpty()
 			? defaultVariant
 			: CurrentEngine->currentStyleVariant();
 	variantChangedSlot(newVariant);
@@ -388,36 +395,37 @@ void ChatStylesManager::preparePreview(Preview *preview)
 
 	Chat chat = Chat::create();
 	chat.setChatAccount(BuddyPreferredManager::instance()->preferredAccount(example));
-	ChatDetailsSimple *details = new ChatDetailsSimple(chat);
+	chat.setType("Simple");
+
+	ChatDetailsSimple *details = dynamic_cast<ChatDetailsSimple *>(chat.details());
 	details->setState(StorableObject::StateNew);
 	details->setContact(BuddyPreferredManager::instance()->preferredContact(example));
-	chat.setDetails(details);
 
 	connect(preview, SIGNAL(destroyed()), chat, SLOT(deleteLater()));
 
-	Message messageSent = Message::create();
-	messageSent.setMessageChat(chat);
-	messageSent.setType(MessageTypeSent);
-	messageSent.setMessageSender(chat.chatAccount().accountContact());
-	messageSent.setContent(tr("Your message"));
-	messageSent.setReceiveDate(QDateTime::currentDateTime());
-	messageSent.setSendDate(QDateTime::currentDateTime());
+	Message sentMessage = Message::create();
+	sentMessage.setMessageChat(chat);
+	sentMessage.setType(MessageTypeSent);
+	sentMessage.setMessageSender(chat.chatAccount().accountContact());
+	sentMessage.setContent(tr("Your message"));
+	sentMessage.setReceiveDate(QDateTime::currentDateTime());
+	sentMessage.setSendDate(QDateTime::currentDateTime());
 
-	MessageRenderInfo *messageRenderInfo = new MessageRenderInfo(messageSent);
+	MessageRenderInfo *messageRenderInfo = new MessageRenderInfo(sentMessage);
 	messageRenderInfo->setSeparatorSize(CfgHeaderSeparatorHeight);
-	preview->addObjectToParse(BuddyPreferredManager::instance()->preferredContact(Core::instance()->myself()), messageRenderInfo);
+	preview->addMessage(messageRenderInfo);
 
-	Message messageReceived = Message::create();
-	messageReceived.setMessageChat(chat);
-	messageReceived.setType(MessageTypeReceived);
-	messageReceived.setMessageSender(BuddyPreferredManager::instance()->preferredContact(example));
-	messageReceived.setContent(tr("Message from Your friend"));
-	messageReceived.setReceiveDate(QDateTime::currentDateTime());
-	messageReceived.setSendDate(QDateTime::currentDateTime());
+	Message receivedMessage = Message::create();
+	receivedMessage.setMessageChat(chat);
+	receivedMessage.setType(MessageTypeReceived);
+	receivedMessage.setMessageSender(BuddyPreferredManager::instance()->preferredContact(example));
+	receivedMessage.setContent(tr("Message from Your friend"));
+	receivedMessage.setReceiveDate(QDateTime::currentDateTime());
+	receivedMessage.setSendDate(QDateTime::currentDateTime());
 
-	messageRenderInfo = new MessageRenderInfo(messageReceived);
+	messageRenderInfo = new MessageRenderInfo(receivedMessage);
 	messageRenderInfo->setSeparatorSize(CfgHeaderSeparatorHeight);
-	preview->addObjectToParse(BuddyPreferredManager::instance()->preferredContact(example), messageRenderInfo);
+	preview->addMessage(messageRenderInfo);
 }
 
 void ChatStylesManager::styleChangedSlot(const QString &styleName)
