@@ -10,6 +10,7 @@
  * Copyright 2003, 2005 Paweł Płuciennik (pawel_p@kadu.net)
  * Copyright 2003, 2004 Dariusz Jagodzik (mast3r@kadu.net)
  * %kadu copyright begin%
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
@@ -79,7 +80,8 @@ EmoticonSelectorButton::MovieViewer::MovieViewer(EmoticonSelectorButton *parent)
 		"}";
 	setStyleSheet(style);
 
-	QMovie *movie = new QMovie(parent->AnimPath);
+	QMovie *movie = new QMovie(this);
+	movie->setFileName(parent->AnimPath);
 	setMovie(movie);
 	if((EmoticonsScaling)config_file.readNumEntry("Chat","EmoticonsScaling") & EmoticonsScalingAnimated)
 		movie->setScaledSize(parent->pixmap()->size());
