@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,12 +25,13 @@
 #include <QtGui/QPushButton>
 #include <QtGui/QVBoxLayout>
 
-#include "avatars/avatar.h"
 #include "avatars/avatar-manager.h"
+#include "avatars/avatar.h"
 #include "icons/kadu-icon.h"
-#include "protocols/services/avatar-service.h"
-#include "protocols/protocol.h"
 #include "protocols/protocol-factory.h"
+#include "protocols/protocols-manager.h"
+#include "protocols/protocol.h"
+#include "protocols/services/avatar-service.h"
 
 #include "account-avatar-widget.h"
 
@@ -41,7 +42,13 @@ AccountAvatarWidget::AccountAvatarWidget(Account account, QWidget *parent) :
 
 	createGui();
 
-	triggerAllProtocolsRegistered();
+	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryRegistered(ProtocolFactory*)),
+	        this, SLOT(protocolRegistered(ProtocolFactory*)));
+	connect(ProtocolsManager::instance(), SIGNAL(protocolFactoryUnregistered(ProtocolFactory*)),
+	        this, SLOT(protocolUnregistered(ProtocolFactory*)));
+
+	foreach (ProtocolFactory *factory, ProtocolsManager::instance()->protocolFactories())
+		protocolRegistered(factory);
 }
 
 AccountAvatarWidget::~AccountAvatarWidget()
