@@ -1,8 +1,14 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2004, 2009 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
+ * Copyright 2007, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,8 +34,7 @@
 
 #include "exports.h"
 
-class QCheckBox;
-class QScrollArea;
+class GroupList;
 
 class KADUAPI BuddyGroupsConfigurationWidget : public QWidget
 {
@@ -37,8 +42,7 @@ class KADUAPI BuddyGroupsConfigurationWidget : public QWidget
 
 	Buddy MyBuddy;
 
-	QScrollArea *Groups;
-	QList<QCheckBox *> GroupCheckBoxList;
+	GroupList *BuddyGroupList;
 
 	void createGui();
 
