@@ -1,7 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -58,15 +59,16 @@ public:
 	ConfigListWidget(ConfigGroupBox *parentConfigGroupBox, ConfigurationWindowDataManager *dataManager);
 	virtual ~ConfigListWidget();
 
+	virtual void setVisible(bool visible);
+
 	void setItems(const QStringList &itemValues, const QStringList &itemCaptions);
 	const QString & currentItemValue() { return itemValues.at(currentRow()); }
 
 	virtual void loadConfiguration() {};
 	virtual void saveConfiguration() {};
 
-	virtual void show();
-	virtual void hide();
 	virtual bool fromDomElement(QDomElement domElement);
+
 };
 
 #endif
