@@ -1,6 +1,9 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +24,8 @@
 #include <QtGui/QLabel>
 #include <QtGui/QListWidget>
 
-#include "gui/widgets/configuration/config-radio-button.h"
 #include "gui/widgets/configuration/config-group-box.h"
+#include "gui/widgets/configuration/config-radio-button.h"
 
 #include "debug.h"
 
@@ -64,13 +67,3 @@ void ConfigRadioButton::saveConfiguration()
 
 	dataManager->writeEntry(section, item, QVariant(isChecked() ? "true" : "false"));
 }
-
-void ConfigRadioButton::show()
-{
-	QRadioButton::show();
-}
-
-void ConfigRadioButton::hide()
-{
-	QRadioButton::hide();
-}
