@@ -1,9 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -24,8 +24,8 @@
 #include <QtGui/QLabel>
 #include <QtXml/QDomElement>
 
-#include "gui/widgets/configuration/config-spin-box.h"
 #include "gui/widgets/configuration/config-group-box.h"
+#include "gui/widgets/configuration/config-spin-box.h"
 
 #include "debug.h"
 
@@ -85,16 +85,10 @@ void ConfigSpinBox::saveConfiguration()
 	dataManager->writeEntry(section, item, QVariant(value()));
 }
 
-void ConfigSpinBox::show()
+void ConfigSpinBox::setVisible(bool visible)
 {
-	label->show();
-	QSpinBox::show();
-}
-
-void ConfigSpinBox::hide()
-{
-	label->hide();
-	QSpinBox::hide();
+	label->setVisible(visible);
+	QSpinBox::setVisible(visible);
 }
 
 bool ConfigSpinBox::fromDomElement(QDomElement domElement)
