@@ -1,14 +1,14 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009, 2011 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2008 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2007, 2008, 2009, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,19 +32,20 @@
 #include <QtGui/QDesktopWidget>
 #include <QtGui/QVBoxLayout>
 
-#include "chat/type/chat-type.h"
 #include "chat/chat-details.h"
 #include "chat/chat-geometry-data.h"
+#include "chat/type/chat-type.h"
 #include "configuration/configuration-file.h"
 #include "contacts/contact-set.h"
-#include "gui/widgets/chat-widget.h"
 #include "gui/widgets/chat-widget-manager.h"
+#include "gui/widgets/chat-widget.h"
 #include "gui/widgets/custom-input.h"
 #include "gui/windows/message-dialog.h"
+#include "message/message-manager.h"
 
+#include "misc/misc.h"
 #include "activate.h"
 #include "debug.h"
-#include "misc/misc.h"
 
 #include "chat-window.h"
 
@@ -54,6 +55,7 @@ ChatWindow::ChatWindow(ChatWidget *chatWidget, QWidget *parent) :
 {
 	kdebugf();
 
+	setProperty("ownWindowIcon", true);
 	setWindowRole("kadu-chat");
 	if (chatWidget && chatWidget->chat().details() && chatWidget->chat().details()->type())
 		setWindowRole(chatWidget->chat().details()->type()->windowRole());
@@ -81,11 +83,7 @@ ChatWindow::ChatWindow(ChatWidget *chatWidget, QWidget *parent) :
 	connect(currentChatWidget, SIGNAL(closed()), this, SLOT(close()));
 	connect(currentChatWidget, SIGNAL(iconChanged()), this, SLOT(updateIcon()));
 	connect(currentChatWidget, SIGNAL(titleChanged(ChatWidget *, const QString &)), this, SLOT(updateTitle()));
-	connect(currentChatWidget, SIGNAL(messageReceived(Chat)), this, SLOT(alertNewMessage()));
 	connect(title_timer, SIGNAL(timeout()), this, SLOT(blinkTitle()));
-	connect(this, SIGNAL(chatWidgetActivated(ChatWidget *)),
-			ChatWidgetManager::instance(), SIGNAL(chatWidgetActivated(ChatWidget *)));
-
 }
 
 ChatWindow::~ChatWindow()
@@ -96,11 +94,11 @@ ChatWindow::~ChatWindow()
 void ChatWindow::configurationUpdated()
 {
 	triggerCompositingStateChanged();
-  
+
 	showNewMessagesNum = config_file.readBoolEntry("Chat", "NewMessagesInChatTitle", false);
 	blinkChatTitle = config_file.readBoolEntry("Chat", "BlinkChatTitle", true);
 
-	if (currentChatWidget->newMessagesCount())
+	if (currentChatWidget->chat().unreadMessagesCount())
 		blinkTitle();
 }
 
@@ -169,11 +167,8 @@ void ChatWindow::kaduStoreGeometry()
 	currentChatWidget->kaduStoreGeometry();
 
 	ChatGeometryData *cgd = currentChatWidget->chat().data()->moduleStorableData<ChatGeometryData>("chat-geometry", ChatWidgetManager::instance(), true);
-	if (!cgd)
-		return;
-
 	cgd->setWindowGeometry(geometry());
-	cgd->store();
+	cgd->ensureStored();
 }
 
 void ChatWindow::closeEvent(QCloseEvent *e)
@@ -185,7 +180,7 @@ void ChatWindow::closeEvent(QCloseEvent *e)
 		unsigned int period = config_file.readUnsignedNumEntry("Chat",
 			"ChatCloseTimerPeriod", 2);
 
-		if (QDateTime::currentDateTime() < currentChatWidget->lastMessageTime().addSecs(period))
+		if (QDateTime::currentDateTime() < currentChatWidget->lastReceivedMessageTime().addSecs(period))
 		{
 			if (!MessageDialog::ask(KaduIcon("dialog-question"), tr("Kadu"), tr("New message received, close window anyway?")))
 			{
@@ -208,7 +203,7 @@ void ChatWindow::updateTitle()
 	setWindowTitle(currentChatWidget->title());
 
 	// TODO 0.10.0: is that really needed here? this method is called only on chat widget title change
-	if (showNewMessagesNum && currentChatWidget->newMessagesCount()) // if we don't have new messages or don't want them to be shown
+	if (showNewMessagesNum && currentChatWidget->chat().unreadMessagesCount()) // if we don't have new messages or don't want them to be shown
 		showNewMessagesNumInTitle();
 }
 
@@ -237,7 +232,7 @@ void ChatWindow::blinkTitle()
 void ChatWindow::showNewMessagesNumInTitle()
 {
 	if (!_isActiveWindow(this))
-		setWindowTitle('[' + QString::number(currentChatWidget->newMessagesCount()) + "] " + currentChatWidget->title());
+		setWindowTitle('[' + QString::number(currentChatWidget->chat().unreadMessagesCount()) + "] " + currentChatWidget->title());
 }
 
 void ChatWindow::changeEvent(QEvent *event)
@@ -248,37 +243,15 @@ void ChatWindow::changeEvent(QEvent *event)
 		kdebugf();
 		if (_isActiveWindow(this))
 		{
-			currentChatWidget->markAllMessagesRead();
+
+			MessageManager::instance()->markAllMessagesAsRead(currentChatWidget->chat());
 			setWindowTitle(currentChatWidget->title());
-
 			title_timer->stop();
-
-			emit chatWidgetActivated(currentChatWidget);
 		}
 		kdebugf2();
 	}
 }
 
-void ChatWindow::alertNewMessage()
-{
-	if (!_isWindowActiveOrFullyVisible(this))
-	{
-		if (blinkChatTitle)
-		{
-			if (!title_timer->isActive())
-				blinkTitle(); // blinking is able to show new messages also...
-			qApp->alert(this); // TODO: make notifier from this
-		}
-		else if (showNewMessagesNum) // ... so we check this condition as 'else'
-		{
-			showNewMessagesNumInTitle();
-			qApp->alert(this); // TODO: make notifier from this
-		}
-	}
-	else
-		currentChatWidget->markAllMessagesRead();
-}
-
 void ChatWindow::setWindowTitle(const QString &title)
 {
 	// qt treats [*] as 'modified placeholder'
@@ -287,9 +260,50 @@ void ChatWindow::setWindowTitle(const QString &title)
 	QWidget::setWindowTitle(escaped.replace(QLatin1String("[*]"), QLatin1String("[*][*]")));
 }
 
+void ChatWindow::activateChatWidget(ChatWidget *chatWidget)
+{
+	Q_UNUSED(chatWidget)
+	Q_ASSERT(chatWidget == currentChatWidget);
+
+	// we can be embeded in other window...
+	_activateWindow(window());
+}
+
+void ChatWindow::alertChatWidget(ChatWidget *chatWidget)
+{
+	Q_UNUSED(chatWidget)
+	Q_ASSERT(chatWidget == currentChatWidget);
+
+	if (isChatWidgetActive(chatWidget))
+	{
+		MessageManager::instance()->markAllMessagesAsRead(currentChatWidget->chat());
+		return;
+	}
+
+	qApp->alert(this); // TODO: make notifier from this
+
+	if (blinkChatTitle)
+	{
+		if (!title_timer->isActive())
+			blinkTitle(); // blinking is able to show new messages also...
+	}
+	else if (showNewMessagesNum) // ... so we check this condition as 'else'
+		showNewMessagesNumInTitle();
+}
+
 void ChatWindow::closeChatWidget(ChatWidget *chatWidget)
 {
 	Q_UNUSED(chatWidget)
+	Q_ASSERT(chatWidget == currentChatWidget);
 
 	close();
 }
+
+bool ChatWindow::isChatWidgetActive(ChatWidget *chatWidget)
+{
+	Q_UNUSED(chatWidget)
+	Q_ASSERT(chatWidget == currentChatWidget);
+
+	return _isWindowActiveOrFullyVisible(this);
+}
+
