@@ -1,8 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,9 +33,10 @@ class QLabel;
 class QPushButton;
 class QVBoxLayout;
 
-class BuddiesListView;
 class BuddyListModel;
 class LineEditWithClearButton;
+class ModelChain;
+class TalkableTreeView;
 
 class KADUAPI OpenChatWith : public QWidget, DesktopAwareObject
 {
@@ -46,12 +48,13 @@ class KADUAPI OpenChatWith : public QWidget, DesktopAwareObject
 
 	bool IsTyping;
 
-	BuddiesListView *BuddiesWidget;
+	TalkableTreeView *BuddiesWidget;
 	LineEditWithClearButton *ContactID;
 	QVBoxLayout *MainLayout;
 	OpenChatWithRunner *OpenChatRunner;
 
 	BuddyListModel *ListModel;
+	ModelChain *Chain;
 
 private slots:
 	void inputAccepted();
