@@ -1,6 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
+ * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -19,11 +22,13 @@
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QPluginLoader>
+#include <QtCore/QTimer>
 #include <QtCore/QTranslator>
 #include <QtGui/QApplication>
 
 #include "configuration/configuration-file.h"
-#include "gui/windows/message-dialog.h"
+#include "gui/windows/modules-window.h"
+#include "gui/windows/plugin-error-dialog.h"
 #include "misc/path-conversion.h"
 #include "plugins/generic-plugin.h"
 #include "plugins/plugin-info.h"
@@ -31,6 +36,17 @@
 
 #include "plugin.h"
 
+#ifdef Q_OS_MAC
+	#define SO_PREFIX "lib"
+	#define SO_EXT "dylib"
+#elif defined(Q_OS_WIN)
+	#define SO_PREFIX ""
+	#define SO_EXT "dll"
+#else
+	#define SO_PREFIX "lib"
+	#define SO_EXT "so"
+#endif
+
 /**
  * @author Rafał 'Vogel' Malinowski
  * @short Creates new Plugin object and loads PluginInfo data.
@@ -112,6 +128,19 @@ void Plugin::store()
 	}
 }
 
+/**
+ * @author Bartosz 'beevvy' Brachaczek
+ * @short Reimplemented from StorableObject::shouldStore().
+ *
+ * Reimplemented from StorableObject::shouldStore(). Returns false if State is PluginStateNew.
+ */
+bool Plugin::shouldStore()
+{
+	ensureLoaded();
+
+	return NamedStorableObject::shouldStore() && PluginStateNew != state();
+}
+
 /**
  * @author Rafał 'Vogel' Malinowski
  * @short Returns true if this plugin should be activated.
@@ -140,6 +169,7 @@ bool Plugin::shouldBeActivated()
 /**
  * @author Rafał 'Vogel' Malinowski
  * @short Activates plugin and retursn true if plugin is active.
+ * @param reason plugin activation reason
  * @return true if plugin is active after method return
  *
  * This method loads plugin library file (if exists) and set up  GenericPlugin object from this library.
@@ -147,24 +177,30 @@ bool Plugin::shouldBeActivated()
  * paramer set to true if this plugin's state  if PluginStateNew. If this methods returns value different
  * than 0, plugin is deactivated and false value is returned.
  *
- * Translations must be loaded before GenericPlugin::init() is called.
+ * Translations must be loaded before the root component of the plugin is instantiated.
  *
  * This method returns true if plugin is active after method returns - especially when plugin was active
  * before this call.
  */
-bool Plugin::activate()
+bool Plugin::activate(PluginActivationReason reason)
 {
 	if (Active)
 		return true;
 
+	ensureLoaded();
+
 	PluginLoader = new QPluginLoader(libPath("kadu/plugins/"SO_PREFIX + Name + "." SO_EXT));
 	PluginLoader->setLoadHints(QLibrary::ExportExternalSymbolsHint);
 
 	if (!PluginLoader->load())
 	{
 		QString err = PluginLoader->errorString();
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Cannot load %1 plugin library.:\n%2").arg(Name, err));
 		kdebugm(KDEBUG_ERROR, "cannot load %s because of: %s\n", qPrintable(Name), qPrintable(err));
+		activationError(tr("Cannot load %1 plugin library.:\n%2").arg(Name, err), reason);
+
+		delete PluginLoader;
+		PluginLoader = 0;
+
 		kdebugf2();
 		return false;
 	}
@@ -175,9 +211,11 @@ bool Plugin::activate()
 	PluginObject = qobject_cast<GenericPlugin *>(PluginLoader->instance());
 	if (!PluginObject)
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Cannot find required object in module %1.\n"
-				"Maybe it's not Kadu-compatible plugin.").arg(Name));
+		activationError(tr("Cannot find required object in module %1.\nMaybe it's not Kadu-compatible plugin.").arg(Name), reason);
 
+		// Refer to deactivate() method for reasons to this.
+		QApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+		PluginLoader->unload();
 		delete PluginLoader;
 		PluginLoader = 0;
 
@@ -191,8 +229,10 @@ bool Plugin::activate()
 
 	if (res != 0)
 	{
-		MessageDialog::show(KaduIcon("dialog-warning"), tr("Kadu"), tr("Module initialization routine for %1 failed.").arg(Name));
+		activationError(tr("Module initialization routine for %1 failed.").arg(Name), reason);
 
+		// Refer to deactivate() method for reasons to this.
+		QApplication::sendPostedEvents(0, QEvent::DeferredDelete);
 		PluginLoader->unload();
 		delete PluginLoader;
 		PluginLoader = 0;
@@ -205,10 +245,20 @@ bool Plugin::activate()
 
 	UsageCounter = 0;
 
-	kdebugf2();
+	/* This is perfectly intentional. We have to set state to either enabled or disabled, as new
+	 * means that it was never loaded. If the only reason to load the plugin was because some other
+	 * plugin depended upon it, set state to disabled as we don't want that plugin to be loaded
+	 * next time when its reverse dependency will not be loaded. Otherwise set state to enabled.
+	 */
+	if (PluginActivationReasonDependency != reason)
+		setState(PluginStateEnabled);
+	else
+		setState(PluginStateDisabled);
 
 	Active = true;
 
+	kdebugf2();
+
 	return true;
 }
 
@@ -216,10 +266,11 @@ bool Plugin::activate()
  * @author Rafał 'Vogel' Malinowski
  * @short Deactivates plugin.
  *
- * If plugin is active, its GenericPlugin::done() method is called and then all data is removed from
- * memory - plugin library file and plugin translations.
+ * If plugin is active, its GenericPlugin::done() method is called. Then all deferred delete
+ * events are sent so that we will not end up trying to delete objects belonging to unloaded
+ * plugins. Finally all data is removed from memory - plugin library file and plugin translations.
  */
-void Plugin::deactivate()
+void Plugin::deactivate(PluginDeactivationReason reason)
 {
 	if (!Active)
 		return;
@@ -227,6 +278,12 @@ void Plugin::deactivate()
 	if (PluginObject)
 		PluginObject->done();
 
+	// We need this because plugins can call deleteLater() just before being
+	// unloaded. In this case control would not return to the event loop before
+	// unloading the plugin and the event loop would try to delete objects
+	// belonging to already unloaded plugins, which can result in segfaults.
+	QApplication::sendPostedEvents(0, QEvent::DeferredDelete);
+
 	if (PluginLoader)
 	{
 		PluginLoader->unload();
@@ -239,6 +296,9 @@ void Plugin::deactivate()
 	unloadTranslations();
 
 	Active = false;
+
+	if (PluginDeactivationReasonUserRequest == reason)
+		setState(PluginStateDisabled);
 }
 
 /**
@@ -286,6 +346,9 @@ void Plugin::unloadTranslations()
  *
  * This method changes state of plugin. Set state to PluginStateEnabled to make this plugin
  * activate at every Kadu run.
+ *
+ * Please do not call this method unless you are absolutely sure the plugin had been loaded
+ * at least once.
  */
 void Plugin::setState(Plugin::PluginState state)
 {
@@ -293,3 +356,45 @@ void Plugin::setState(Plugin::PluginState state)
 
 	State = state;
 }
+
+/**
+ * @author Bartosz 'beevvy' Brachaczek
+ * @short Sets state enablement of plugin if it is inactive.
+ *
+ * If this plugin is active or its state is PluginStateNew, this method does nothing.
+ *
+ * Otherwise, this method sets its state to PluginStateEnabled if \p enable is true.
+ * If \p enable is false, this method sets the plugin's state to PluginStateDisabled.
+ */
+void Plugin::setStateEnabledIfInactive(bool enable)
+{
+	if (isActive())
+		return;
+
+	if (PluginStateNew == state())
+		return;
+
+	setState(enable ? PluginStateEnabled : PluginStateDisabled);
+}
+
+/**
+ * @author Bartosz 'beevvy' Brachaczek
+ * @short Shows activation error to the user.
+ * @param errorMessage error message that will be displayer to the user
+ * @param activationReason plugin activation reason
+ * @todo it really shouldn't call gui classes directly
+ *
+ * This method creates new PluginErrorDialog with message \p errorMessage and opens it. Depending on
+ * \p activationReason, it also intructs the dialog wheter to offer the user choice wheter to try
+ * to load this plugin automatically in future.
+ */
+void Plugin::activationError(const QString &errorMessage, PluginActivationReason activationReason)
+{
+	bool offerLoadInFutureChoice = (PluginActivationReasonKnownDefault == activationReason);
+
+	PluginErrorDialog *errorDialog = new PluginErrorDialog(errorMessage, offerLoadInFutureChoice, ModulesWindow::instance());
+	if (offerLoadInFutureChoice)
+		connect(errorDialog, SIGNAL(accepted(bool)), this, SLOT(setStateEnabledIfInactive(bool)));
+
+	QTimer::singleShot(0, errorDialog, SLOT(open()));
+}
