@@ -1,8 +1,8 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,7 @@
 StandardUrlHandler::StandardUrlHandler()
 {
 	// TODO: WTF? fix it!!!!!!!!!!!!!!!!!!!!!!!
-	UrlRegExp = QRegExp("\\b(http://|https://|www\\.|ftp://|ftp\\.|sftp://|smb://|file:/|rsync://|svn://|svn\\+ssh://)(\\w|[a-zA-Z0-9ąśężźćółń\\*\\-\\._/~?=&#\\+%\\(\\)\\[\\]:;,!@\\\\])*");
+	UrlRegExp = QRegExp("\\b(http://|https://|www\\.|ftp://)(\\w|[a-zA-Z0-9ąśężźćółń\\*\\-\\._/~?=&#\\+%\\(\\)\\[\\]:;,!@\\\\])*");
 
 	configurationUpdated();
 }
@@ -57,7 +57,6 @@ void StandardUrlHandler::convertUrlsToHtml(HtmlDocument &document, bool generate
 		QString displayLink = Qt::escape(text.mid(index, length));
 		QString aLink = displayLink;
 
-		aLink.replace("%20", "%2520"); // Opera's bug workaround - allows opening links with spaces
 		if (!aLink.contains("://"))
 			aLink.prepend("http://");
 
