@@ -19,18 +19,10 @@
             <numerusform>%n sekund</numerusform>
         </translation>
     </message>
-    <message>
-        <source>Show message content in hint</source>
-        <translation>Ukázat obsah zprávy v bublině</translation>
-    </message>
     <message>
         <source>Number of quoted characters</source>
         <translation>Počet citovaných znaků</translation>
     </message>
-    <message>
-        <source>System</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>System notifications</source>
         <translation type="unfinished"></translation>
@@ -43,5 +35,9 @@
         <source>Expiration timeout</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show message content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
