@@ -18,18 +18,10 @@
             <numerusform>%n seconds</numerusform>
         </translation>
     </message>
-    <message>
-        <source>Show message content in hint</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Number of quoted characters</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>System</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>System notifications</source>
         <translation type="unfinished"></translation>
@@ -42,5 +34,9 @@
         <source>Expiration timeout</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show message content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
