@@ -1,11 +1,17 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2010, 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2008 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
+ * Copyright 2004 Tomasz Chiliński (chilek@chilan.com)
+ * Copyright 2007, 2008, 2009, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2006, 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2004, 2005, 2006, 2007 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -119,6 +125,8 @@ private:
 	void connectedToServer();
 	void disconnectedFromServer();
 
+	void setStatusFlags();
+
 private slots:
 	void accountUpdated();
 
@@ -159,8 +167,9 @@ public:
 
 	virtual int maxDescriptionLength();
 
+	void enableSocketNotifiers();
+	void disableSocketNotifiers();
 	gg_session * gaduSession() { return GaduSession; }
-	GaduProtocolSocketNotifiers * socketNotifiers() { return SocketNotifiers; }
 
 signals:
 	/**
