@@ -1,6 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,13 +24,15 @@
 #ifndef GADU_PROTOCOL_HELPER_H
 #define GADU_PROTOCOL_HELPER_H
 
+#include "status/status-type.h"
+
 #include "gadu-exports.h"
 
 #include "gadu-protocol.h"
 
 namespace GaduProtocolHelper
 {
-	GADUAPI QString statusTypeFromGaduStatus(unsigned int index);
+	GADUAPI StatusType statusTypeFromGaduStatus(unsigned int index);
 	GADUAPI bool isBlockingStatus(unsigned int index);
 	GADUAPI unsigned int gaduStatusFromStatus(const Status &status);
 
