@@ -1,6 +1,8 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -17,9 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "contacts/contact.h"
 #include "contacts/contact-manager.h"
 #include "contacts/contact-set.h"
+#include "contacts/contact.h"
 
 #include "helpers/gadu-protocol-helper.h"
 #include "gadu-account-details.h"
@@ -76,7 +78,9 @@ void GaduChatStateService::composingStarted(const Chat &chat)
 	if (!Protocol->gaduSession())
 		return;
 
+	static_cast<GaduProtocol *>(Protocol)->disableSocketNotifiers();
 	gg_typing_notification(Protocol->gaduSession(), GaduProtocolHelper::uin(contact), 0x0001);
+	static_cast<GaduProtocol *>(Protocol)->enableSocketNotifiers();
 }
 
 void GaduChatStateService::composingStopped(const Chat &chat)
@@ -91,7 +95,9 @@ void GaduChatStateService::composingStopped(const Chat &chat)
 	if (!Protocol->gaduSession())
 		return;
 
+	static_cast<GaduProtocol *>(Protocol)->disableSocketNotifiers();
 	gg_typing_notification(Protocol->gaduSession(), GaduProtocolHelper::uin(contact), 0x0000);
+	static_cast<GaduProtocol *>(Protocol)->enableSocketNotifiers();
 }
 
 void GaduChatStateService::chatWidgetClosed(const Chat &chat)
