@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -26,18 +26,16 @@
 #include <QtCore/QByteArray>
 
 #include "buddies/buddy-manager.h"
-#include "contacts/contact.h"
 #include "contacts/contact-manager.h"
-#include "contacts/contact-shared.h"
+#include "contacts/contact.h"
 #include "core/core.h"
 #include "misc/misc.h"
 #include "debug.h"
 
 #include "helpers/gadu-list-helper.h"
+#include "services/gadu-contact-list-state-machine.h"
 #include "gadu-account-details.h"
 #include "gadu-protocol.h"
-#include "services/gadu-contact-list-state-machine.h"
-#include "socket-notifiers/gadu-protocol-socket-notifiers.h"
 
 #include "gadu-contact-list-service.h"
 
@@ -204,7 +202,11 @@ void GaduContactListService::importContactList()
 {
 	ContactListService::importContactList();
 
-	if (-1 == gg_userlist100_request(Protocol->gaduSession(), GG_USERLIST100_GET, 0, GG_USERLIST100_FORMAT_TYPE_GG70, 0))
+	static_cast<GaduProtocol *>(protocol())->disableSocketNotifiers();
+	int ret = gg_userlist100_request(Protocol->gaduSession(), GG_USERLIST100_GET, 0, GG_USERLIST100_FORMAT_TYPE_GG70, 0);
+	static_cast<GaduProtocol *>(protocol())->enableSocketNotifiers();
+
+	if (-1 == ret)
 	{
 		emit stateMachineInternalError();
 		emit contactListImported(false, BuddyList());
@@ -223,9 +225,15 @@ void GaduContactListService::exportContactList(const BuddyList &buddies)
 	kdebugmf(KDEBUG_NETWORK|KDEBUG_INFO, "\n%s\n", contacts.constData());
 
 	GaduAccountDetails *accountDetails = dynamic_cast<GaduAccountDetails *>(Protocol->account().details());
-	if (!accountDetails || -1 == gg_userlist100_request(
-			Protocol->gaduSession(), GG_USERLIST100_PUT, accountDetails->userlistVersion(),
-			GG_USERLIST100_FORMAT_TYPE_GG70, contacts.constData()))
+	if (!accountDetails)
+		emit stateMachineInternalError();
+
+	static_cast<GaduProtocol *>(protocol())->disableSocketNotifiers();
+	int ret = gg_userlist100_request(Protocol->gaduSession(),
+			GG_USERLIST100_PUT, accountDetails->userlistVersion(), GG_USERLIST100_FORMAT_TYPE_GG70, contacts.constData());
+	static_cast<GaduProtocol *>(protocol())->enableSocketNotifiers();
+
+	if (-1 == ret)
 		emit stateMachineInternalError();
 }
 
