@@ -1,9 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,7 +30,6 @@
 #include "dcc/dcc-socket-notifiers.h"
 #include "file-transfer/gadu-file-transfer-handler.h"
 #include "helpers/gadu-protocol-helper.h"
-#include "socket-notifiers/gadu-protocol-socket-notifiers.h"
 #include "gadu-account-details.h"
 #include "gadu-contact-details.h"
 #include "gadu-protocol.h"
@@ -74,10 +76,7 @@ bool GaduFileTransferService::connectionAcceptable(UinType uin, UinType peerUin)
 	if (!gaduAccountDetails)
 		return false;
 
-	Contact contact = ContactManager::instance()->byId(Protocol->account(), QString::number(peerUin));
-	if (contact.isNull())
-		return false;
-
+	Contact contact = ContactManager::instance()->byId(Protocol->account(), QString::number(peerUin), ActionReturnNull);
 	Buddy buddy = contact.ownerBuddy();
 	if (uin != gaduAccountDetails->uin() || buddy.isAnonymous())
 	{
@@ -119,6 +118,7 @@ void GaduFileTransferService::handleEventDcc7New(struct gg_event *e)
 
 	if (!connectionAcceptable(dcc->uin, dcc->peer_uin) || GG_DCC7_TYPE_FILE != dcc->dcc_type)
 	{
+		// No need to reenable socket notifiers as we close connection here.
 		gg_dcc7_reject(dcc, 0);
 		gg_dcc7_free(dcc);
 		return;
