@@ -1,6 +1,13 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
+ * Copyright 2007, 2009, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
+ * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,13 +32,15 @@
 struct DatesModelItem
 {
 	QDate Date;
-	int Count;
 	QString Title;
+	int Count;
 
-	DatesModelItem(const QDate &date, int count, const QString &title)
-		: Date(date), Count(count), Title(title)
+	DatesModelItem() {}
+	DatesModelItem(const QDate &date, const QString &title, int count) :
+			Date(date), Title(title), Count(count)
 	{
 	}
+
 };
 
 #endif // DATES_MODEL_ITEM_H
