@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
+ * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -23,11 +23,12 @@
 
 #include <QtCore/QFile>
 #include <QtCore/QList>
+#include <QtCore/QThread>
 #include <QtCore/QTimer>
 #include <QtGui/QProgressDialog>
 
-#include "accounts/account.h"
 #include "accounts/account-manager.h"
+#include "accounts/account.h"
 #include "configuration/configuration-file.h"
 #include "core/core.h"
 #include "gui/windows/kadu-window.h"
@@ -56,7 +57,7 @@ HistoryImporter::~HistoryImporter()
 	if (Thread)
 	{
 		disconnect(Thread, SIGNAL(finished()), this, SLOT(threadFinished()));
-		Thread->cancel(true);
+		ImportThread->cancel(true);
 		Thread->wait(2000);
 		if (Thread->isRunning())
 		{
@@ -94,8 +95,14 @@ void HistoryImporter::run()
 		return;
 	}
 
-	Thread = new HistoryImportThread(DestinationAccount, SourceDirectory, uinsLists, totalEntries, this);
-	connect(Thread, SIGNAL(finished()), this, SLOT(threadFinished()));
+	ImportThread = new HistoryImportThread(DestinationAccount, SourceDirectory, uinsLists, totalEntries);
+	ImportThread->prepareChats();
+
+	Thread = new QThread();
+	ImportThread->moveToThread(Thread);
+
+	connect(Thread, SIGNAL(started()), ImportThread, SLOT(run()));
+	connect(ImportThread, SIGNAL(finished()), this, SLOT(threadFinished()));
 
 	ProgressWindow = new HistoryImportWindow();
 	ProgressWindow->setChatsCount(uinsLists.size());
@@ -113,17 +120,17 @@ void HistoryImporter::run()
 
 void HistoryImporter::updateProgressWindow()
 {
-	if (ProgressWindow && Thread)
+	if (ProgressWindow && ImportThread)
 	{
-		ProgressWindow->setChatsProgress(Thread->importedChats());
-		ProgressWindow->setMessagesCount(Thread->totalMessages());
-		ProgressWindow->setMessagesProgress(Thread->importedMessages());
+		ProgressWindow->setChatsProgress(ImportThread->importedChats());
+		ProgressWindow->setMessagesCount(ImportThread->totalMessages());
+		ProgressWindow->setMessagesProgress(ImportThread->importedMessages());
 	}
 }
 
 void HistoryImporter::threadFinished()
 {
-	if (Thread && !Thread->wasCanceled() && SourceDirectory == profilePath("history/"))
+	if (ImportThread && !ImportThread->wasCanceled() && SourceDirectory == profilePath("history/"))
 	{
 		config_file.writeEntry("History", "Imported_from_0.6.5", true);
 		// this is no longer useful
