@@ -1,9 +1,12 @@
 /*
  * %kadu copyright begin%
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2008, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,15 +23,13 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "contacts/contact-shared.h"
-
 #include "iris/xmpp.h"
 #include "utils/jid-util.h"
 
 #include "jabber-contact-details.h"
 
-JabberContactDetails::JabberContactDetails(ContactShared *contactShared, QObject *parent) :
-		ContactDetails(contactShared, parent)
+JabberContactDetails::JabberContactDetails(ContactShared *contactShared) :
+		ContactDetails(contactShared), IgnoreNextStatusChange(false)
 {
 	ContactSubscription = XMPP::Subscription();
 }
@@ -36,7 +37,3 @@ JabberContactDetails::JabberContactDetails(ContactShared *contactShared, QObject
 JabberContactDetails::~JabberContactDetails()
 {
 }
-
-void JabberContactDetails::store()
-{
-}
