@@ -1,11 +1,11 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2009, 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Michał Podsiadlik (michal@kadu.net)
- * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2009, 2009 Bartłomiej Zimoń (uzi18@o2.pl)
+ * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -25,18 +25,18 @@
 #include <QtGui/QTextDocument>
 
 #include "buddies/buddy-set.h"
-#include "chat/chat.h"
 #include "chat/chat-manager.h"
-#include "chat/message/message.h"
-#include "core/core.h"
+#include "chat/chat.h"
 #include "configuration/configuration-file.h"
-#include "contacts/contact-set.h"
 #include "contacts/contact-manager.h"
+#include "contacts/contact-set.h"
+#include "core/core.h"
 #include "gui/windows/message-dialog.h"
+#include "message/message.h"
 #include "misc/misc.h"
 
-#include "html_document.h"
 #include "debug.h"
+#include "html_document.h"
 
 #include "../jabber-protocol.h"
 
@@ -47,6 +47,8 @@ JabberChatService::JabberChatService(JabberProtocol *protocol)
 {
 	connect(protocol->client(), SIGNAL(messageReceived(const XMPP::Message &)),
 		this, SLOT(clientMessageReceived(const XMPP::Message &)));
+
+        ContactMessageTypes = new QMap<QString, QString>();
 }
 
 bool JabberChatService::sendMessage(const Chat &chat, FormattedMessage &formattedMessage, bool silent)
@@ -78,7 +80,11 @@ bool JabberChatService::sendMessage(const Chat &chat, FormattedMessage &formatte
 	    return false;
 	}
 
-	msg.setType("chat");
+	QString messageType = false == ContactMessageTypes->value(jus.bare()).isEmpty()
+                        ? ContactMessageTypes->value(jus.bare())
+                        : "chat";
+
+	msg.setType(messageType);
 	msg.setBody(plain);
 	msg.setTimeStamp(QDateTime::currentDateTime());
 	//msg.setFrom(jabberID);
@@ -133,6 +139,12 @@ void JabberChatService::clientMessageReceived(const XMPP::Message &msg)
 	if (ignore)
 		return;
 
+        QString messageType = msg.type().isEmpty()
+                        ? "message"
+                        : msg.type();
+
+        ContactMessageTypes->insert(msg.from().bare(), messageType);
+
 	HtmlDocument::escapeText(plain);
 
 	Message message = Message::create();
