@@ -107,6 +107,13 @@
         <translation>E-mail:</translation>
     </message>
 </context>
+<context>
+    <name>CertificateErrorDialog</name>
+    <message>
+        <source>The %1 certificate failed the authenticity test.</source>
+        <translation type="unfinished">Osvědčení %1 neprošlo zkouškou pravosti.</translation>
+    </message>
+</context>
 <context>
     <name>FacebookProtocolFactory</name>
     <message>
@@ -196,10 +203,6 @@
 </context>
 <context>
     <name>JabberActions</name>
-    <message>
-        <source>Show XML Console for Account</source>
-        <translation>Ukázat konzoli XML pro účet</translation>
-    </message>
     <message>
         <source>Resend Subscription</source>
         <translation>Poslat přihlášení znovu</translation>
@@ -254,12 +257,6 @@
         <source>Change Password</source>
         <translation>Změnit heslo</translation>
     </message>
-    <message>
-        <source>This dialog box allows you to change your current password.
-</source>
-        <translation>Toto dialogové okénko vám umožní změnu vašeho současného hesla.
-</translation>
-    </message>
     <message>
         <source>Old Password</source>
         <translation>Staré heslo</translation>
@@ -477,10 +474,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Connection</source>
         <translation>Připojení</translation>
     </message>
-    <message>
-        <source>Proxy</source>
-        <translation>Proxy</translation>
-    </message>
     <message>
         <source>Manually specify server host/port</source>
         <translation>Stanovit hostitele/přípojku serveru ručně</translation>
@@ -581,6 +574,18 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Remove account</source>
         <translation>Odstranit účet</translation>
     </message>
+    <message>
+        <source>Proxy configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Privacy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publish system information</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>JabberPersonalInfoWidget</name>
@@ -698,10 +703,6 @@ Podrobnosti: %1</translation>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>The %1 certificate failed the authenticity test.</source>
-        <translation>Osvědčení %1 neprošlo zkouškou pravosti.</translation>
-    </message>
     <message>
         <source>&amp;Details...</source>
         <translation>&amp;Podrobnosti...</translation>
@@ -811,6 +812,13 @@ Podrobnosti: %1</translation>
         <translation>Různé</translation>
     </message>
 </context>
+<context>
+    <name>ShowXmlConsoleActionDescription</name>
+    <message>
+        <source>Show XML Console</source>
+        <translation>Ukázat konzoli XML</translation>
+    </message>
+</context>
 <context>
     <name>TestDlg</name>
     <message>
