@@ -107,6 +107,13 @@
         <translation>E-Mail:</translation>
     </message>
 </context>
+<context>
+    <name>CertificateErrorDialog</name>
+    <message>
+        <source>The %1 certificate failed the authenticity test.</source>
+        <translation type="unfinished">Das Zertifikat %1 bestand den Zulassungstest nicht.</translation>
+    </message>
+</context>
 <context>
     <name>FacebookProtocolFactory</name>
     <message>
@@ -196,10 +203,6 @@
 </context>
 <context>
     <name>JabberActions</name>
-    <message>
-        <source>Show XML Console for Account</source>
-        <translation>Zeige XML-Konsole für das Konto</translation>
-    </message>
     <message>
         <source>Resend Subscription</source>
         <translation>Abonnement erneut senden</translation>
@@ -254,11 +257,6 @@
         <source>Change Password</source>
         <translation>Passwort ändern</translation>
     </message>
-    <message>
-        <source>This dialog box allows you to change your current password.
-</source>
-        <translation>Dieses Fenster erlaubt Ihnen, das aktuelle Passwort zu ändern.</translation>
-    </message>
     <message>
         <source>Old Password</source>
         <translation>Altes Passwort</translation>
@@ -476,10 +474,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Connection</source>
         <translation>Verbindung</translation>
     </message>
-    <message>
-        <source>Proxy</source>
-        <translation>Proxy</translation>
-    </message>
     <message>
         <source>Manually specify server host/port</source>
         <translation>Den Rechnernamen und Port selber angeben</translation>
@@ -580,6 +574,18 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Remove account</source>
         <translation>Konto entfernen</translation>
     </message>
+    <message>
+        <source>Proxy configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Privacy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publish system information</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>JabberPersonalInfoWidget</name>
@@ -696,10 +702,6 @@ Genauer gesagt: %1</translation>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>The %1 certificate failed the authenticity test.</source>
-        <translation>Das Zertifikat %1 bestand den Zulassungstest nicht.</translation>
-    </message>
     <message>
         <source>&amp;Details...</source>
         <translation>&amp;Details...</translation>
@@ -809,6 +811,13 @@ Genauer gesagt: %1</translation>
         <translation>Andere</translation>
     </message>
 </context>
+<context>
+    <name>ShowXmlConsoleActionDescription</name>
+    <message>
+        <source>Show XML Console</source>
+        <translation>Zeige XML-Konsole</translation>
+    </message>
+</context>
 <context>
     <name>TestDlg</name>
     <message>
