@@ -107,6 +107,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>CertificateErrorDialog</name>
+    <message>
+        <source>The %1 certificate failed the authenticity test.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FacebookProtocolFactory</name>
     <message>
@@ -196,10 +203,6 @@
 </context>
 <context>
     <name>JabberActions</name>
-    <message>
-        <source>Show XML Console for Account</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Resend Subscription</source>
         <translation type="unfinished"></translation>
@@ -254,11 +257,6 @@
         <source>Change Password</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This dialog box allows you to change your current password.
-</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Old Password</source>
         <translation type="unfinished"></translation>
@@ -476,10 +474,6 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Connection</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Proxy</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Manually specify server host/port</source>
         <translation type="unfinished"></translation>
@@ -580,6 +574,18 @@ Password entered in both fields (&quot;New password&quot; and &quot;Retype passw
         <source>Remove account</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Proxy configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Privacy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publish system information</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>JabberPersonalInfoWidget</name>
@@ -693,10 +699,6 @@ Details: %1</source>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>The %1 certificate failed the authenticity test.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Details...</source>
         <translation type="unfinished"></translation>
@@ -806,6 +808,13 @@ Details: %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ShowXmlConsoleActionDescription</name>
+    <message>
+        <source>Show XML Console</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>TestDlg</name>
     <message>
