@@ -119,7 +119,7 @@ Měl by být větší.</translation>
     </message>
 </context>
 <context>
-    <name>ScreenshotActions</name>
+    <name>ScreenshotAction</name>
     <message>
         <source>ScreenShot</source>
         <translation>Snímek obrazovky</translation>
