@@ -117,7 +117,7 @@ It should be bigger.</source>
     </message>
 </context>
 <context>
-    <name>ScreenshotActions</name>
+    <name>ScreenshotAction</name>
     <message>
         <source>ScreenShot</source>
         <translation type="unfinished"></translation>
