@@ -60,4 +60,11 @@
         <translation>Přepnout zaměření mezi rozpisem služeb a kartami</translation>
     </message>
 </context>
+<context>
+    <name>SingleWindow</name>
+    <message>
+        <source>Conference [%1]</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
