@@ -27,6 +27,14 @@ GatewayEra.prototype = {
 		return "02";
 	},
 
+	maxLength: function() {
+		return 0;
+	},
+
+	signatureRequired: function() {
+		return true;
+	},
+
 	sendSms: function(recipient, signature, content, callbackObject) {
 		var sender = new EraGatewaySmsSender();
 		sender.sendSms(recipient, signature, content, callbackObject);
@@ -82,6 +90,7 @@ EraGatewaySmsSender.prototype = {
 			return;
 		}
 
+		network.setHeader("Content-Type", "application/x-www-form-urlencoded");
 		network.setUtf8(false);
 		this.reply = network.post(postUrl, postData);
 		this.reply.finished.connect(this, this.smsSent);
