@@ -1,10 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2008, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2009 Tomasz Rostański (rozteck@interia.pl)
+ * Copyright 2008, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +21,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "spellchecker.h"
 #include "spellchecker-plugin.h"
+#include "spellchecker.h"
 
 #include "highlighter.h"
 
@@ -66,6 +66,7 @@ void Highlighter::setHighlightFormat(const QTextCharFormat &format)
 
 void Highlighter::removeAll()
 {
-	qDeleteAll(Highlighters);
-	Highlighters.clear();
+	foreach (Highlighter *highlighter, Highlighters)
+		delete highlighter;
+	Q_ASSERT(Highlighters.isEmpty());
 }
